@@ -1,25 +1,8 @@
-/***************************************************************************
-                          kmagview.h  -  description
-                             -------------------
-    begin                : Mon Feb 12 23:45:41 EST 2001
-    copyright            : (C) 2001-2003 by Sarang Lakare
-    email                : sarang#users.sf.net
-    copyright            : (C) 2003-2004 by Olaf Schmidt
-    email                : ojschmidt@kde.org
-    copyright            : (C) 2008 by Matthew Woehlke
-    email                : mw_triad@users.sourceforge.net
-    copyright              (C) 2010 Sebastian Sauer
-    email                  sebsauer@kdab.com
- ***************************************************************************/
-
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2001-2003 Sarang Lakare <sarang@users.sourceforge.net>
+// SPDX-FileCopyrightText: 2003-2004 Olaf Schmidt <ojschmidt@kde.org>
+// SPDX-FileCopyrightText: 2008 Matthew Woehlke <mw_triad@users.sourceforge.net>
+// SPDX-FileCopyrightText: 2010 Sebastian Sauer <sebsauer@kdab.com>
+// SPDX-License-Identifier: GPL-2.0-or-later
 
 #ifndef KMagZoomView_h
 #define KMagZoomView_h
